/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  'page.plugin.drawer.popconfirm.title.delete': '确定删除该插件吗？',
  'page.plugin.list': '插件列表',
  'page.plugin.list.enabled': '已启用插件的列表',
  'page.plugin.market.config': '全局插件列表',
  'page.plugin.edit': '配置插件成功',
  'page.plugin.delete': '删除插件成功',
};
